@@ -6,3 +6,6 @@ import os
 _here = os.path.dirname(__file__)
 
 default = open(os.path.join(_here, 'default.qss'), 'r', encoding='utf8').read()
+
+foldIcon = os.path.join(_here, 'images', 'fold.png')
+fixedIcon = os.path.join(_here, 'images', 'fixed.png')
